Strategies
==========

Base Classes
------------

.. automodule:: quaver.strategies.base
   :members:
   :undoc-members:
   :show-inheritance:

Registry
--------

.. automodule:: quaver.strategies.registry
   :members:
   :undoc-members:
   :show-inheritance:

Indicators
----------

.. automodule:: quaver.strategies.indicators
   :members:
   :undoc-members:
   :show-inheritance:

Mean Reversion
--------------

.. automodule:: quaver.strategies.mean_reversion
   :members:
   :undoc-members:
   :show-inheritance:

Regime Mean Reversion
---------------------

.. automodule:: quaver.strategies.regime_mean_reversion
   :members:
   :undoc-members:
   :show-inheritance:

VSA Stopping Volume
-------------------

.. automodule:: quaver.strategies.vsa_stopping_volume
   :members:
   :undoc-members:
   :show-inheritance:

Pairs Mean Reversion
--------------------

.. automodule:: quaver.strategies.pairs_mean_reversion
   :members:
   :undoc-members:
   :show-inheritance:

Breakout from Consolidation
---------------------------

.. automodule:: quaver.strategies.breakout_consolidation
   :members:
   :undoc-members:
   :show-inheritance:

Pullback in Trend
-----------------

.. automodule:: quaver.strategies.pullback_trend
   :members:
   :undoc-members:
   :show-inheritance:

Reversal at Support
-------------------

.. automodule:: quaver.strategies.reversal_support
   :members:
   :undoc-members:
   :show-inheritance:
